@@ -1,10 +1,5 @@
 package App::FfmpegUtils;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-12-12'; # DATE
-our $DIST = 'App-FfmpegUtils'; # DIST
-our $VERSION = '0.009'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -12,6 +7,11 @@ use Log::ger;
 
 use Perinci::Exporter;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-09-20'; # DATE
+our $DIST = 'App-FfmpegUtils'; # DIST
+our $VERSION = '0.010'; # VERSION
+
 our %SPEC;
 
 $SPEC{':package'} = {
@@ -281,6 +281,10 @@ _
             req => 1,
             pos => 1,
         },
+        copy => {
+            summary => 'Whether to use the "copy" codec (fast but produces inaccurate timings)',
+            schema => 'bool*',
+        },
         # XXX merge_if_last_part_is_shorter_than => {},
         # XXX output_filename_pattern
     },
@@ -331,7 +335,71 @@ sub split_video_by_duration {
         my $time_start = ($i-1)*$part_dur;
         IPC::System::Options::system(
             {log=>1, dry_run=>$args{-dry_run}},
-            "ffmpeg", "-i", $file, "-c", "copy", "-ss", $time_start, "-t", $part_dur, $ofile);
+            "ffmpeg", "-i", $file, ($args{copy} ? ("-c", "copy") : ()), "-ss", $time_start, "-t", $part_dur, $ofile);
+    }
+    [200];
+}
+
+$SPEC{cut_video_by_duration} = {
+    v => 1.1,
+    summary => 'Get a portion (time range) of a video',
+    description => <<'_',
+
+This utility uses *ffmpeg* (particularly the `-t` and `-ss`) option to get a
+portion (time range) of a video. It is a convenient wrapper of ffmpeg for this
+particular task. You can specify start time and end time, or start time and
+duration. It automatically chooses a filename if you don't specify one.
+
+_
+    args => {
+        %arg0_file,
+        start => {
+            schema => 'duration*',
+            req => 1,
+            pos => 1,
+        },
+    },
+    examples => [
+    ],
+    features => {
+        dry_run => 1,
+    },
+    deps => {
+        prog => "ffmpeg", # XXX allow FFMPEG_PATH
+    },
+    links => [
+        {url=>'prog:srtsplit', summary=>'Split .srt by duration, much like this utility'},
+    ],
+};
+sub cut_video_by_duration {
+    require POSIX;
+
+    my %args = @_;
+    my $file = $args{file};
+    my $part_dur = $args{every};
+    $part_dur > 0 or return [400, "Please specify a non-zero --every"];
+
+    require Media::Info;
+    my $res = Media::Info::get_media_info(media => $file);
+    return $res unless $res->[0] == 200;
+
+    my $total_dur = $res->[2]{duration}
+        or return [412, "Duration of video is zero"];
+
+    my $num_parts = POSIX::ceil($total_dur / $part_dur);
+    my $fmt = $num_parts >= 1000 ? "%04d" : $num_parts >= 100 ? "%03d" : $num_parts >= 10 ? "%02d" : "%d";
+
+    return [304, "No split necessary"] if $num_parts < 2;
+
+    require IPC::System::Options;
+    for my $i (1..$num_parts) {
+        my $part_label = sprintf "${fmt}of%d", $i, $num_parts;
+        my $ofile = $file;
+        if ($ofile =~ /\.\w+\z/) { $ofile =~ s/(\.\w+)\z/.$part_label$1/ } else { $ofile .= ".$part_label" }
+        my $time_start = ($i-1)*$part_dur;
+        IPC::System::Options::system(
+            {log=>1, dry_run=>$args{-dry_run}},
+            "ffmpeg", "-i", $file, ($args{copy} ? ("-c", "copy") : ()), "-ss", $time_start, "-t", $part_dur, $ofile);
     }
     [200];
 }
@@ -351,16 +419,68 @@ App::FfmpegUtils - Utilities related to ffmpeg
 
 =head1 VERSION
 
-This document describes version 0.009 of App::FfmpegUtils (from Perl distribution App-FfmpegUtils), released on 2020-12-12.
+This document describes version 0.010 of App::FfmpegUtils (from Perl distribution App-FfmpegUtils), released on 2022-09-20.
 
 =head1 FUNCTIONS
 
 
+=head2 cut_video_by_duration
+
+Usage:
+
+ cut_video_by_duration(%args) -> [$status_code, $reason, $payload, \%result_meta]
+
+Get a portion (time range) of a video.
+
+This utility uses I<ffmpeg> (particularly the C<-t> and C<-ss>) option to get a
+portion (time range) of a video. It is a convenient wrapper of ffmpeg for this
+particular task. You can specify start time and end time, or start time and
+duration. It automatically chooses a filename if you don't specify one.
+
+This function is not exported.
+
+This function supports dry-run operation.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<file>* => I<filename>
+
+=item * B<start>* => I<duration>
+
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-dry_run> => I<bool>
+
+Pass -dry_run=E<gt>1 to enable simulation mode.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
+
+
+
 =head2 reencode_video_with_libx264
 
 Usage:
 
- reencode_video_with_libx264(%args) -> [status, msg, payload, meta]
+ reencode_video_with_libx264(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Re-encode video (using ffmpeg and libx264).
 
@@ -450,12 +570,12 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -465,7 +585,7 @@ Return value:  (any)
 
 Usage:
 
- split_video_by_duration(%args) -> [status, msg, payload, meta]
+ split_video_by_duration(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Split video by duration into parts.
 
@@ -489,6 +609,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<copy> => I<bool>
+
+Whether to use the "copy" codec (fast but produces inaccurate timings).
+
 =item * B<every>* => I<duration>
 
 =item * B<file>* => I<filename>
@@ -508,12 +632,12 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -525,23 +649,41 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Ffmpeg
 
 Source repository is at L<https://github.com/perlancar/perl-App-FfmpegUtils>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-FfmpegUtils/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-FfmpegUtils>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
